'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var rxjs = require('rxjs');

var getHistoryEventObservable = function getHistoryEventObservable() {
  var w = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : window;
  return new rxjs.Observable(function (subscriber) {
    var originPushState = w.history.pushState;
    var originReplaceState = w.history.replaceState;

    var patchedPushState = function patchedPushState(state, title, url) {
      // NOTE: to avoid `TypeError: Illegal invocation`
      originPushState.call(w.history, state, title, url);
      subscriber.next(w.location.href);
    };

    var patchedReplaceState = function patchedReplaceState(state, title, url) {
      // NOTE: to avoid `TypeError: Illegal invocation`
      originReplaceState.call(w.history, state, title, url);
      subscriber.next(w.location.href);
    };

    var onPopstate = function onPopstate() {
      return subscriber.next(w.location.href);
    };

    w.history.pushState = patchedPushState.bind(w.history);
    w.history.replaceState = patchedReplaceState.bind(w.history);
    w.addEventListener('popstate', onPopstate);
    return function () {
      w.history.pushState = originPushState;
      w.history.replaceState = originReplaceState;
      w.removeEventListener('popstate', onPopstate);
    };
  });
};

exports.getHistoryEventObservable = getHistoryEventObservable;
//# sourceMappingURL=observable.js.map
