'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var constants = require('../constants.js');
var util = require('./util.js');

var toSocketIoMessagePayload = function toSocketIoMessagePayload(id, data) {
  return "".concat(constants.packetTypes.send).concat(id).concat(JSON.stringify(['socket.io-request', data]));
}; // 430[{...}}] => 430, [{}]
// @see https://github.com/socketio/engine.io-protocol

var parseMessage = function parseMessage(message) {
  var packetType = '';

  while (message.length) {
    var head = message[0];

    if (util.isIntegerString(head)) {
      packetType += head;
      message = message.substr(1);
    } else {
      return [packetType, JSON.parse(message)];
    }
  }

  return [packetType, undefined];
};
var isConnectionMessage = function isConnectionMessage(message) {
  return message[0] === constants.packetTypes.initialize;
};
var isResponseMessage = function isResponseMessage(message) {
  return message[0].length > 2 && message[0].startsWith(constants.packetTypes.response);
};
var getRequestId = function getRequestId(packetType) {
  return packetType.slice(2);
};
var isResponseMessageOf = function isResponseMessageOf(sid) {
  return function (message) {
    return isResponseMessage(message) && sid === getRequestId(message[0]);
  };
};

exports.getRequestId = getRequestId;
exports.isConnectionMessage = isConnectionMessage;
exports.isResponseMessage = isResponseMessage;
exports.isResponseMessageOf = isResponseMessageOf;
exports.parseMessage = parseMessage;
exports.toSocketIoMessagePayload = toSocketIoMessagePayload;
//# sourceMappingURL=message.js.map
