'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var rxjs = require('rxjs');
var operators = require('rxjs/operators');
var env = require('../../common/env.js');

var getBrowserWebSocket = function getBrowserWebSocket(_ref) {
  var endpoint = _ref.endpoint;
  return new WebSocket(endpoint);
};
var getNodeJSWebSocket = function getNodeJSWebSocket(_ref2) {
  var endpoint = _ref2.endpoint,
      origin = _ref2.origin,
      cookie = _ref2.cookie;

  var NodeWebsocket = require('ws');

  var headers = {
    Origin: origin,
    Cookie: cookie
  };
  return new NodeWebsocket(endpoint, undefined, {
    headers: headers
  });
};
var getWebSocket = function getWebSocket(settings) {
  if (env.isBrowser()) {
    // @TODO: validate settings
    return getBrowserWebSocket(settings);
  } else {
    // @TODO: validate settings
    return getNodeJSWebSocket(settings);
  }
};
var getEventStream = function getEventStream(socket) {
  var close = rxjs.fromEvent(socket, 'close').pipe(operators.first());
  var open = rxjs.fromEvent(socket, 'open').pipe(operators.takeUntil(close), operators.shareReplay());
  var error = rxjs.fromEvent(socket, 'error').pipe(operators.takeUntil(close), operators.shareReplay());
  var message = rxjs.fromEvent(socket, 'message').pipe(operators.takeUntil(close));
  return {
    open: open,
    close: close,
    error: error,
    message: message
  };
};

exports.getBrowserWebSocket = getBrowserWebSocket;
exports.getEventStream = getEventStream;
exports.getNodeJSWebSocket = getNodeJSWebSocket;
exports.getWebSocket = getWebSocket;
//# sourceMappingURL=websocket.js.map
