'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _rollupPluginBabelHelpers = require('../../_virtual/_rollupPluginBabelHelpers.js');
var rxjs = require('rxjs');
var operators = require('rxjs/operators');
var constants = require('./constants.js');
var message = require('./internal/message.js');
var request = require('./internal/request.js');
var util = require('./internal/util.js');
var websocket = require('./internal/websocket.js');

var WebsocketClient = /*#__PURE__*/function () {
  // currently joined-room, need cache to re-join on reconnect
  // wait request until connection opened
  function WebsocketClient() {
    var config = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    _rollupPluginBabelHelpers.classCallCheck(this, WebsocketClient);

    _rollupPluginBabelHelpers.defineProperty(this, "config", void 0);

    _rollupPluginBabelHelpers.defineProperty(this, "socket", void 0);

    _rollupPluginBabelHelpers.defineProperty(this, "open$", void 0);

    _rollupPluginBabelHelpers.defineProperty(this, "error$", void 0);

    _rollupPluginBabelHelpers.defineProperty(this, "close$", void 0);

    _rollupPluginBabelHelpers.defineProperty(this, "message$", void 0);

    _rollupPluginBabelHelpers.defineProperty(this, "room", null);

    _rollupPluginBabelHelpers.defineProperty(this, "sid", 0);

    this.config = config;
    this.initialize();
  }

  _rollupPluginBabelHelpers.createClass(WebsocketClient, [{
    key: "commit",
    value: function commit(params) {
      return this.send({
        method: 'commit',
        data: {
          kind: 'page',
          userId: params.userId,
          projectId: params.projectId,
          pageId: params.pageId,
          parentId: params.parentId,
          changes: request.createChanges(params.changes, params.userId),
          cursor: null,
          freeze: true
        }
      });
    }
  }, {
    key: "join",
    value: function join(params) {
      this.room = params;
      return this.send({
        method: 'room:join',
        data: {
          pageId: params.pageId,
          projectId: params.projectId,
          projectUpdatesStream: false
        }
      });
    }
  }, {
    key: "initialize",
    value: function initialize() {
      this.socket = this.openWebSocket();

      var _getEventStream = websocket.getEventStream(this.socket),
          open = _getEventStream.open,
          error = _getEventStream.error,
          close = _getEventStream.close,
          message$1 = _getEventStream.message;

      this.open$ = open.pipe(operators.shareReplay());
      this.error$ = error.pipe(operators.shareReplay());
      this.close$ = close.pipe(operators.shareReplay());
      this.message$ = message$1.pipe(operators.map(function (event) {
        return message.parseMessage(event.data);
      }));
      this.registerInitializationOnOpen();
      this.registerReconnectionOnClose();
    }
  }, {
    key: "send",
    value: function () {
      var _send = _rollupPluginBabelHelpers.asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(data) {
        var sid, message$1;
        return regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                sid = String(this.sid++);
                message$1 = message.toSocketIoMessagePayload(sid, data);
                this.socket.send(message$1);
                return _context.abrupt("return", rxjs.firstValueFrom(this.message$.pipe(operators.first(message.isResponseMessageOf(sid)), operators.timeout(constants.CONFIG.responseTimeout))));

              case 4:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function send(_x) {
        return _send.apply(this, arguments);
      }

      return send;
    }()
  }, {
    key: "openWebSocket",
    value: function openWebSocket() {
      var _this$config$websocke, _this$config$token;

      var getSocket = (_this$config$websocke = this.config.websocketConstructor) !== null && _this$config$websocke !== void 0 ? _this$config$websocke : websocket.getWebSocket;
      return getSocket(_rollupPluginBabelHelpers.objectSpread2(_rollupPluginBabelHelpers.objectSpread2({}, constants.CONFIG), {}, {
        cookie: util.getCookieToAuth((_this$config$token = this.config.token) !== null && _this$config$token !== void 0 ? _this$config$token : '')
      }));
    }
  }, {
    key: "registerInitializationOnOpen",
    value: function registerInitializationOnOpen() {
      var _this = this;

      this.message$.pipe(operators.first(message.isConnectionMessage)).subscribe(function (_ref) {
        var _ref2 = _rollupPluginBabelHelpers.slicedToArray(_ref, 2),
            data = _ref2[1];

        _this.socket.send(constants.packetTypes.connected); // start ping


        rxjs.interval(data.pingInterval).pipe(operators.takeUntil(_this.close$)).subscribe(function () {
          return _this.socket.send(constants.packetTypes.ping);
        }); // for reconnection after closed

        if (_this.room) {
          _this.join(_this.room);
        }
      });
    }
  }, {
    key: "registerReconnectionOnClose",
    value: function registerReconnectionOnClose() {
      var _this2 = this;

      this.close$.subscribe(function () {
        return _this2.initialize();
      });
    }
  }]);

  return WebsocketClient;
}();

exports.WebsocketClient = WebsocketClient;
//# sourceMappingURL=websocket-client.js.map
