'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var rxjs = require('rxjs');
var operators = require('rxjs/operators');

var findElementOrFail = function findElementOrFail(selector) {
  var parent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : document;
  var elem = parent.querySelector(selector);

  if (!elem) {
    throw new Error('Element not found');
  }

  return elem;
};
var nodeChange = function nodeChange(node, options) {
  return new rxjs.Observable(function (subscriber) {
    var mo = new MutationObserver(function () {
      return subscriber.next();
    });
    mo.observe(node, options);
    return function () {
      return mo.disconnect();
    };
  }).pipe(operators.share());
}; // NOTE: scrapbox.Project.name is set after react bootstrapped

var isScrapboxReady = function isScrapboxReady() {
  return Boolean(window.scrapbox.Project && window.scrapbox.Project.name);
};
var scrapboxReady = function scrapboxReady() {
  return new rxjs.Observable(function (subscriber) {
    var subscription = rxjs.timer(0, 30).subscribe(function () {
      if (isScrapboxReady()) {
        subscriber.next(window.scrapbox);
        subscriber.complete();
        subscription.unsubscribe();
      }
    });
    return subscription;
  });
};

exports.findElementOrFail = findElementOrFail;
exports.isScrapboxReady = isScrapboxReady;
exports.nodeChange = nodeChange;
exports.scrapboxReady = scrapboxReady;
//# sourceMappingURL=util.js.map
